@@ -2,6 +2,7 @@ import io
 import os
 import sys
 import json
+import stat
 import time
 import fcntl
 import heapq
@@ -382,13 +383,46 @@ def reqdir(*paths):
 
     Args:
         *paths ([str,...]): A list of path elements
-        **opts:  arguments as kwargs to os.makedirs
     '''
     path = genpath(*paths)
     if not os.path.isdir(path):
         raise s_exc.NoSuchDir(path=path)
     return path
 
+def getDirSize(*paths):
+    '''
+    Returns:
+        Tuple of total real and total apparent size of all normal files and directories underneath *paths plus *paths
+        itself
+
+        Equivalent to `du -B 1 -s` and `du -bs`
+
+    Args:
+        *paths ([str,...]): A list of path elements
+    '''
+    def getsize(path):
+        try:
+            status = os.lstat(path)
+        except OSError:  # pragma: no cover
+            return 0, 0
+
+        mode = status.st_mode
+        if not (stat.S_ISREG(mode) or stat.S_ISDIR(mode)):
+            return 0, 0
+
+        return status.st_blocks * 512, status.st_size
+
+    realsum, apprsum = getsize(genpath(*paths))
+
+    for fpath, dirnames, fnames in os.walk(reqdir(*paths)):
+        for fname in itertools.chain(fnames, dirnames):
+            fp = genpath(fpath, fname)
+            real, appr = getsize(fp)
+            realsum += real
+            apprsum += appr
+
+    return realsum, apprsum
+
 def jsload(*paths):
     with genfile(*paths) as fd:
         byts = fd.read()
@@ -443,7 +477,7 @@ def excinfo(e):
     '''
     Populate err,errmsg,errtrace info from exc.
     '''
-    tb = sys.exc_info()[2]
+    tb = e.__traceback__
     path, line, name, sorc = traceback.extract_tb(tb)[-1]
     ret = {
         'err': e.__class__.__name__,
@@ -636,6 +670,34 @@ def _getLogConfFromEnv(defval=None, structlog=None):
     ret = {'defval': defval, 'structlog': structlog}
     return ret
 
+def normLogLevel(valu):
+    '''
+    Norm a log level value to a integer.
+
+    Args:
+        valu: The value to norm ( a string or integer ).
+
+    Returns:
+        int: A valid Logging log level.
+    '''
+    if isinstance(valu, int):
+        if valu not in s_const.LOG_LEVEL_INVERSE_CHOICES:
+            raise s_exc.BadArg(mesg=f'Invalid log level provided: {valu}', valu=valu)
+        return valu
+    if isinstance(valu, str):
+        valu = valu.strip()
+        try:
+            valu = int(valu)
+        except ValueError:
+            valu = valu.upper()
+            ret = s_const.LOG_LEVEL_CHOICES.get(valu)
+            if ret is None:
+                raise s_exc.BadArg(mesg=f'Invalid log level provided: {valu}', valu=valu) from None
+            return ret
+        else:
+            return normLogLevel(valu)
+    raise s_exc.BadArg(mesg=f'Unknown log level type: {type(valu)} {valu}', valu=valu)
+
 def setlogging(mlogger, defval=None, structlog=None):
     '''
     Configure synapse logging.
@@ -656,10 +718,8 @@ def setlogging(mlogger, defval=None, structlog=None):
     log_struct = ret.get('structlog')
 
     if log_level:  # pragma: no cover
-        if isinstance(log_level, str):
-            log_level = log_level.upper()
-            if log_level not in s_const.LOG_LEVEL_CHOICES:
-                raise ValueError('Invalid log level provided: {}'.format(log_level))
+
+        log_level = normLogLevel(log_level)
 
         if log_struct:
             handler = logging.StreamHandler()
@@ -668,7 +728,7 @@ def setlogging(mlogger, defval=None, structlog=None):
             logging.basicConfig(level=log_level, handlers=(handler,))
         else:
             logging.basicConfig(level=log_level, format=s_const.LOG_FORMAT)
-        mlogger.info('log level set to %s', log_level)
+        mlogger.info('log level set to %s', s_const.LOG_LEVEL_INVERSE_CHOICES.get(log_level))
 
     return ret
 
