@@ -5,6 +5,7 @@ import regex  # type: ignore
 import synapse.exc as s_exc
 
 import synapse.lib.ast as s_ast
+import synapse.lib.coro as s_coro
 import synapse.lib.cache as s_cache
 import synapse.lib.datfile as s_datfile
 
@@ -176,6 +177,10 @@ class AstConverter(lark.Transformer):
         kid = self._convert_child(kids[-1])
         return s_ast.YieldValu(kids=[kid])
 
+    @lark.v_args(meta=True)
+    def evalvalu(self, kids, meta):
+        return self._convert_child(kids[0])
+
     @lark.v_args(meta=True)
     def lookup(self, kids, meta):
         kids = self._convert_children(kids)
@@ -360,9 +365,8 @@ class AstConverter(lark.Transformer):
 with s_datfile.openDatFile('synapse.lib/storm.lark') as larkf:
     _grammar = larkf.read().decode()
 
-QueryParser = lark.Lark(_grammar, regex=True, start='query', propagate_positions=True)
-LookupParser = lark.Lark(_grammar, regex=True, start='lookup', propagate_positions=True)
-CmdrParser = lark.Lark(_grammar, regex=True, start='cmdrargs', propagate_positions=True)
+LarkParser = lark.Lark(_grammar, regex=True, start=['query', 'lookup', 'cmdrargs', 'evalvalu'],
+                       propagate_positions=True)
 
 class Parser:
     '''
@@ -398,6 +402,17 @@ class Parser:
 
         return s_exc.BadSyntax(at=at, text=self.text, mesg=mesg)
 
+    def eval(self):
+        try:
+            tree = LarkParser.parse(self.text, start='evalvalu')
+            newtree = AstConverter(self.text).transform(tree)
+
+        except lark.exceptions.LarkError as e:
+            raise self._larkToSynExc(e) from None
+
+        newtree.text = self.text
+        return newtree
+
     def query(self):
         '''
         Parse the storm query
@@ -405,7 +420,7 @@ class Parser:
         Returns (s_ast.Query):  instance of parsed query
         '''
         try:
-            tree = QueryParser.parse(self.text)
+            tree = LarkParser.parse(self.text, start='query')
             newtree = AstConverter(self.text).transform(tree)
 
         except lark.exceptions.LarkError as e:
@@ -416,7 +431,7 @@ class Parser:
 
     def lookup(self):
         try:
-            tree = LookupParser.parse(self.text)
+            tree = LarkParser.parse(self.text, start='lookup')
         except lark.exceptions.LarkError as e:
             raise self._larkToSynExc(e) from None
         newtree = AstConverter(self.text).transform(tree)
@@ -428,12 +443,11 @@ class Parser:
         Parse command args that might have storm queries as arguments
         '''
         try:
-            tree = CmdrParser.parse(self.text)
+            tree = LarkParser.parse(self.text, start='cmdrargs')
         except lark.exceptions.LarkError as e:
             raise self._larkToSynExc(e) from None
         return AstConverter(self.text).transform(tree)
 
-@s_cache.memoize(size=100)
 def parseQuery(text, mode='storm'):
     '''
     Parse a storm query and return the Lark AST.  Cached here to speed up unit tests
@@ -448,6 +462,18 @@ def parseQuery(text, mode='storm'):
 
     return Parser(text).query()
 
+def parseEval(text):
+    return Parser(text).eval()
+
+async def _forkedParseQuery(args):
+    return await s_coro.forked(parseQuery, args[0], mode=args[1])
+
+async def _forkedParseEval(text):
+    return await s_coro.forked(parseEval, text)
+
+evalcache = s_cache.FixedCache(_forkedParseEval, size=100)
+querycache = s_cache.FixedCache(_forkedParseQuery, size=100)
+
 def massage_vartokn(x):
     return s_ast.Const('' if not x else (x[1:-1] if x[0] == "'" else (unescape(x) if x[0] == '"' else x)))
 
