@@ -149,61 +149,61 @@ class DnsModule(s_module.CoreModule):
 
             'forms': (
                 ('inet:dns:a', {}, (
-                    ('fqdn', ('inet:fqdn', {}), {'ro': 1,
+                    ('fqdn', ('inet:fqdn', {}), {'ro': True,
                         'doc': 'The domain queried for its DNS A record.'}),
-                    ('ipv4', ('inet:ipv4', {}), {'ro': 1,
+                    ('ipv4', ('inet:ipv4', {}), {'ro': True,
                         'doc': 'The IPv4 address returned in the A record.'}),
                 )),
                 ('inet:dns:aaaa', {}, (
-                    ('fqdn', ('inet:fqdn', {}), {'ro': 1,
+                    ('fqdn', ('inet:fqdn', {}), {'ro': True,
                          'doc': 'The domain queried for its DNS AAAA record.'}),
-                    ('ipv6', ('inet:ipv6', {}), {'ro': 1,
+                    ('ipv6', ('inet:ipv6', {}), {'ro': True,
                          'doc': 'The IPv6 address returned in the AAAA record.'}),
                 )),
                 ('inet:dns:rev', {}, (
-                    ('ipv4', ('inet:ipv4', {}), {'ro': 1,
+                    ('ipv4', ('inet:ipv4', {}), {'ro': True,
                          'doc': 'The IPv4 address queried for its DNS PTR record.'}),
-                    ('fqdn', ('inet:fqdn', {}), {'ro': 1,
+                    ('fqdn', ('inet:fqdn', {}), {'ro': True,
                          'doc': 'The domain returned in the PTR record.'}),
                 )),
                 ('inet:dns:rev6', {}, (
-                    ('ipv6', ('inet:ipv6', {}), {'ro': 1,
+                    ('ipv6', ('inet:ipv6', {}), {'ro': True,
                          'doc': 'The IPv6 address queried for its DNS PTR record.'}),
-                    ('fqdn', ('inet:fqdn', {}), {'ro': 1,
+                    ('fqdn', ('inet:fqdn', {}), {'ro': True,
                          'doc': 'The domain returned in the PTR record.'}),
                 )),
                 ('inet:dns:ns', {}, (
-                    ('zone', ('inet:fqdn', {}), {'ro': 1,
+                    ('zone', ('inet:fqdn', {}), {'ro': True,
                          'doc': 'The domain queried for its DNS NS record.'}),
-                    ('ns', ('inet:fqdn', {}), {'ro': 1,
+                    ('ns', ('inet:fqdn', {}), {'ro': True,
                          'doc': 'The domain returned in the NS record.'}),
                 )),
                 ('inet:dns:cname', {}, (
-                    ('fqdn', ('inet:fqdn', {}), {'ro': 1,
+                    ('fqdn', ('inet:fqdn', {}), {'ro': True,
                          'doc': 'The domain queried for its CNAME record.'}),
-                    ('cname', ('inet:fqdn', {}), {'ro': 1,
+                    ('cname', ('inet:fqdn', {}), {'ro': True,
                          'doc': 'The domain returned in the CNAME record.'}),
                 )),
                 ('inet:dns:mx', {}, (
-                    ('fqdn', ('inet:fqdn', {}), {'ro': 1,
+                    ('fqdn', ('inet:fqdn', {}), {'ro': True,
                          'doc': 'The domain queried for its MX record.'}),
-                    ('mx', ('inet:fqdn', {}), {'ro': 1,
+                    ('mx', ('inet:fqdn', {}), {'ro': True,
                          'doc': 'The domain returned in the MX record.'}),
                 )),
 
                 ('inet:dns:soa', {}, (
-                    ('fqdn', ('inet:fqdn', {}), {'ro': 1,
+                    ('fqdn', ('inet:fqdn', {}), {'ro': True,
                          'doc': 'The domain queried for its SOA record.'}),
-                    ('ns', ('inet:fqdn', {}), {'ro': 1,
+                    ('ns', ('inet:fqdn', {}), {'ro': True,
                          'doc': 'The domain (MNAME) returned in the SOA record.'}),
-                    ('email', ('inet:email', {}), {'ro': 1,
+                    ('email', ('inet:email', {}), {'ro': True,
                          'doc': 'The email address (RNAME) returned in the SOA record.'}),
                 )),
 
                 ('inet:dns:txt', {}, (
-                    ('fqdn', ('inet:fqdn', {}), {'ro': 1,
+                    ('fqdn', ('inet:fqdn', {}), {'ro': True,
                          'doc': 'The domain queried for its TXT record.'}),
-                    ('txt', ('str', {}), {'ro': 1,
+                    ('txt', ('str', {}), {'ro': True,
                          'doc': 'The string returned in the TXT record.'}),
                 )),
 
@@ -278,16 +278,16 @@ class DnsModule(s_module.CoreModule):
                 )),
 
                 ('inet:dns:wild:a', {}, (
-                    ('fqdn', ('inet:fqdn', {}), {'ro': 1,
+                    ('fqdn', ('inet:fqdn', {}), {'ro': True,
                         'doc': 'The domain containing a wild card record.'}),
-                    ('ipv4', ('inet:ipv4', {}), {'ro': 1,
+                    ('ipv4', ('inet:ipv4', {}), {'ro': True,
                         'doc': 'The IPv4 address returned by wild card resolutions.'}),
                 )),
 
                 ('inet:dns:wild:aaaa', {}, (
-                    ('fqdn', ('inet:fqdn', {}), {'ro': 1,
+                    ('fqdn', ('inet:fqdn', {}), {'ro': True,
                         'doc': 'The domain containing a wild card record.'}),
-                    ('ipv6', ('inet:ipv6', {}), {'ro': 1,
+                    ('ipv6', ('inet:ipv6', {}), {'ro': True,
                         'doc': 'The IPv6 address returned by wild card resolutions.'}),
                 )),
             )
