@@ -8,13 +8,14 @@ from unittest import mock
 
 import synapse.exc as s_exc
 import synapse.common as s_common
+import synapse.daemon as s_daemon
 import synapse.telepath as s_telepath
 
 import synapse.lib.base as s_base
 import synapse.lib.cell as s_cell
-import synapse.lib.coro as s_coro
 import synapse.lib.link as s_link
 import synapse.lib.version as s_version
+import synapse.lib.lmdbslab as s_lmdbslab
 
 import synapse.tests.utils as s_t_utils
 
@@ -29,17 +30,20 @@ def _exiterProc(pipe, srcdir, dstdir, lmdbpaths, logconf):
     pipe.send('captured')
     sys.exit(1)
 
-def _backupSleep(path, linkinfo, done):
+def _backupSleep(path, linkinfo):
     time.sleep(3.0)
 
-async def _iterBackupEOF(path, linkinfo, done):
+async def _doEOFBackup(path):
+    return
+
+async def _iterBackupEOF(path, linkinfo):
     link = await s_link.fromspawn(linkinfo)
+    await s_daemon.t2call(link, _doEOFBackup, (path,), {})
     link.writer.write_eof()
     await link.fini()
-    await s_coro.executor(done.put, True)
 
-def _backupEOF(path, linkinfo, done):
-    asyncio.run(_iterBackupEOF(path, linkinfo, done))
+def _backupEOF(path, linkinfo):
+    asyncio.run(_iterBackupEOF(path, linkinfo))
 
 class EchoAuthApi(s_cell.CellApi):
 
@@ -615,6 +619,32 @@ class CellTest(s_t_utils.SynTest):
                 self.nn(slab['lockmemory'])
                 self.nn(slab['recovering'])
 
+    async def test_cell_system_info(self):
+        with self.getTestDir() as dirn:
+            backdirn = os.path.join(dirn, 'backups')
+            coredirn = os.path.join(dirn, 'cortex')
+
+            async with self.getTestCore(dirn=coredirn) as core:
+                async with core.getLocalProxy() as proxy:
+                    info = await proxy.getSystemInfo()
+                    for prop in ('osversion', 'pyversion'):
+                        self.nn(info.get(prop))
+
+                    for prop in ('volsize', 'volfree', 'celluptime', 'cellrealdisk',
+                                 'cellapprdisk', 'totalmem', 'availmem'):
+                        self.lt(0, info.get(prop))
+
+            conf = {'backup:dir': backdirn}
+            async with self.getTestCore(conf=conf, dirn=coredirn) as core:
+                async with core.getLocalProxy() as proxy:
+                    info = await proxy.getSystemInfo()
+                    for prop in ('osversion', 'pyversion'):
+                        self.nn(info.get(prop))
+
+                    for prop in ('volsize', 'volfree', 'backupvolsize', 'backupvolfree', 'celluptime', 'cellrealdisk',
+                                 'cellapprdisk', 'totalmem', 'availmem'):
+                        self.lt(0, info.get(prop))
+
     async def test_cell_hiveapi(self):
 
         async with self.getTestCore() as core:
@@ -628,7 +658,7 @@ class CellTest(s_t_utils.SynTest):
 
     async def test_cell_confprint(self):
 
-        with self.withSetLoggingMock():
+        async with self.withSetLoggingMock():
 
             with self.getTestDir() as dirn:
 
@@ -688,6 +718,15 @@ class CellTest(s_t_utils.SynTest):
 
                 async with core.getLocalProxy() as proxy:
 
+                    info = await proxy.getBackupInfo()
+                    self.none(info['currduration'])
+                    self.none(info['laststart'])
+                    self.none(info['lastend'])
+                    self.none(info['lastduration'])
+                    self.none(info['lastsize'])
+                    self.none(info['lastupload'])
+                    self.none(info['lastexception'])
+
                     with self.raises(s_exc.BadArg):
                         await proxy.runBackup('../woot')
 
@@ -695,19 +734,61 @@ class CellTest(s_t_utils.SynTest):
                         with mock.patch.object(s_cell.Cell, '_backupProc', staticmethod(_sleeperProc)):
                             await self.asyncraises(s_exc.SynErr, proxy.runBackup())
 
+                    info = await proxy.getBackupInfo()
+                    errinfo = info.get('lastexception')
+                    laststart1 = info['laststart']
+                    self.eq(errinfo['err'], 'SynErr')
+
                     # Test runners can take an unusually long time to spawn a process
                     with mock.patch.object(s_cell.Cell, 'BACKUP_SPAWN_TIMEOUT', 8.0):
 
                         with mock.patch.object(s_cell.Cell, '_backupProc', staticmethod(_sleeper2Proc)):
                             await self.asyncraises(s_exc.SynErr, proxy.runBackup())
 
+                        info = await proxy.getBackupInfo()
+                        laststart2 = info['laststart']
+                        self.ne(laststart1, laststart2)
+                        errinfo = info.get('lastexception')
+                        self.eq(errinfo['err'], 'SynErr')
+
                         with mock.patch.object(s_cell.Cell, '_backupProc', staticmethod(_exiterProc)):
                             await self.asyncraises(s_exc.SpawnExit, proxy.runBackup())
 
+                        info = await proxy.getBackupInfo()
+                        laststart3 = info['laststart']
+                        self.ne(laststart2, laststart3)
+                        errinfo = info.get('lastexception')
+                        self.eq(errinfo['err'], 'SpawnExit')
+
+                    # Create a rando slab inside cell dir
+                    slabpath = s_common.genpath(coredirn, 'randoslab')
+                    async with await s_lmdbslab.Slab.anit(slabpath):
+                        pass
+
                     name = await proxy.runBackup()
                     self.eq((name,), await proxy.getBackups())
+
+                    info = await proxy.getBackupInfo()
+                    self.none(info['currduration'])
+                    laststart4 = info['laststart']
+                    self.ne(laststart3, laststart4)
+                    self.lt(0, info['lastsize'])
+                    self.nn(info['lastend'])
+                    self.lt(0, info['lastduration'])
+                    self.none(info['lastexception'])
+                    self.none(info['lastupload'])
+
+                    # look inside backup
+                    backups = await proxy.getBackups()
+                    self.len(1, backups)
+                    backupdir = s_common.reqdir(backdirn, backups[0])
+                    s_common.reqpath(backupdir, 'cell.yaml')
+                    s_common.reqpath(backupdir, 'randoslab', 'data.mdb')
+
                     await proxy.delBackup(name)
                     self.eq((), await proxy.getBackups())
+                    self.false(os.path.exists(backupdir))
+
                     name = await proxy.runBackup(name='foo/bar')
 
                     with self.raises(s_exc.BadArg):
@@ -740,7 +821,8 @@ class CellTest(s_t_utils.SynTest):
                     self.nn(await proxy.getCellIden())
 
                 with self.raises(s_exc.BadCertHost):
-                    async with await s_telepath.openurl(f'ssl://root@127.0.0.1:{port}?hostname=borked.localhost') as proxy:
+                    url = f'ssl://root@127.0.0.1:{port}?hostname=borked.localhost'
+                    async with await s_telepath.openurl(url) as proxy:
                         pass
 
     async def test_cell_auth_ctor(self):
@@ -975,6 +1057,15 @@ class CellTest(s_t_utils.SynTest):
 
                     self.eq(('bkup', 'bkup2'), sorted(await proxy.getBackups()))
 
+                    # Start another backup while one is already running
+                    bkup = s_t_utils.alist(proxy.iterNewBackupArchive('runbackup', remove=True))
+                    task = core.schedCoro(bkup)
+                    await asyncio.sleep(0)
+
+                    fail = s_t_utils.alist(proxy.iterNewBackupArchive('alreadyrunning', remove=True))
+                    await self.asyncraises(s_exc.BackupAlreadyRunning, fail)
+                    await asyncio.wait_for(task, 5)
+
             with tarfile.open(bkuppath, 'r:gz') as tar:
                 tar.extractall(path=dirn)
 
@@ -1022,9 +1113,8 @@ class CellTest(s_t_utils.SynTest):
                         async for msg in proxy.iterNewBackupArchive(remove=True):
                             bkup5.write(msg)
 
-                    with self.raises(s_exc.LinkShutDown):
-                        with mock.patch('synapse.lib.cell._iterBackupProc', _backupEOF):
-                            await s_t_utils.alist(proxy.iterNewBackupArchive('eof', remove=True))
+                    with mock.patch('synapse.lib.cell._iterBackupProc', _backupEOF):
+                        await s_t_utils.alist(proxy.iterNewBackupArchive('eof', remove=True))
 
             with tarfile.open(bkuppath5, 'r:gz') as tar:
                 bkupname = os.path.commonprefix(tar.getnames())
