@@ -143,18 +143,23 @@ class InetModelTest(s_t_utils.SynTest):
     async def test_asnet4(self):
         formname = 'inet:asnet4'
         async with self.getTestCore() as core:
+            valu = ('54959', ('1.2.3.4', '5.6.7.8'))
+            expected_ndef = (formname, (54959, (16909060, 84281096)))
+            expected_props = {
+                'net4:min': 16909060,
+                'net4': (16909060, 84281096),
+                'net4:max': 84281096,
+                'asn': 54959,
+            }
+            expected_nodes = (
+                ('inet:ipv4', 16909060),
+                ('inet:ipv4', 84281096),
+            )
             async with await core.snap() as snap:
 
-                valu = ('54959', ('1.2.3.4', '5.6.7.8'))
-                expected_ndef = (formname, (54959, (16909060, 84281096)))
-                expected_props = {
-                    'net4:min': 16909060,
-                    'net4': (16909060, 84281096),
-                    'net4:max': 84281096,
-                    'asn': 54959,
-                }
                 node = await snap.addNode(formname, valu)
                 self.checkNode(node, (expected_ndef, expected_props))
+            await self.checkNodes(core, expected_nodes)
 
     async def test_asnet6(self):
         async with self.getTestCore() as core:
@@ -165,6 +170,11 @@ class InetModelTest(s_t_utils.SynTest):
             self.eq(('ff::', 'ff::100'), nodes[0].get('net6'))
             self.eq('ff::', nodes[0].get('net6:min'))
             self.eq('ff::100', nodes[0].get('net6:max'))
+            expected_nodes = (
+                ('inet:ipv6', 'ff::'),
+                ('inet:ipv6', 'ff::100'),
+            )
+            await self.checkNodes(core, expected_nodes)
 
     async def test_cidr4(self):
         formname = 'inet:cidr4'
@@ -332,7 +342,11 @@ class InetModelTest(s_t_utils.SynTest):
             'dst:host': 32 * 'e',
             'dst:proc': 32 * 'f',
             'dst:exe': 64 * '0',
-            'dst:txbytes': 2
+            'dst:txbytes': 2,
+            'src:softnames': ('hehe', 'haha'),
+            'dst:softnames': ('foobar', 'bazfaz'),
+            'src:cpes': ('cpe:2.3:a:zzz:yyy:*:*:*:*:*:*:*:*', 'cpe:2.3:a:aaa:bbb:*:*:*:*:*:*:*:*'),
+            'dst:cpes': ('cpe:2.3:a:zzz:yyy:*:*:*:*:*:*:*:*', 'cpe:2.3:a:aaa:bbb:*:*:*:*:*:*:*:*'),
         }
         expected_props = {
             'time': 0,
@@ -353,7 +367,11 @@ class InetModelTest(s_t_utils.SynTest):
             'dst:host': 32 * 'e',
             'dst:proc': 32 * 'f',
             'dst:exe': 'sha256:' + 64 * '0',
-            'dst:txbytes': 2
+            'dst:txbytes': 2,
+            'src:softnames': ('haha', 'hehe'),
+            'dst:softnames': ('bazfaz', 'foobar'),
+            'src:cpes': ('cpe:2.3:a:aaa:bbb:*:*:*:*:*:*:*:*', 'cpe:2.3:a:zzz:yyy:*:*:*:*:*:*:*:*'),
+            'dst:cpes': ('cpe:2.3:a:aaa:bbb:*:*:*:*:*:*:*:*', 'cpe:2.3:a:zzz:yyy:*:*:*:*:*:*:*:*'),
         }
         expected_ndef = (formname, 32 * 'a')
         async with self.getTestCore() as core:
@@ -1330,18 +1348,23 @@ class InetModelTest(s_t_utils.SynTest):
 
     async def test_urlredir(self):
         formname = 'inet:urlredir'
-        valu = ('https://vertex.link/idk', 'https://cool.vertex.link:443/something_else')
+        valu = ('https://vertex.link/idk', 'https://cool.vertex.newp:443/something_else')
         expected_props = {
             'src': 'https://vertex.link/idk',
             'src:fqdn': 'vertex.link',
-            'dst': 'https://cool.vertex.link:443/something_else',
-            'dst:fqdn': 'cool.vertex.link',
+            'dst': 'https://cool.vertex.newp:443/something_else',
+            'dst:fqdn': 'cool.vertex.newp',
         }
         expected_ndef = (formname, valu)
+        expected_nodes = (
+            ('inet:fqdn', 'vertex.link'),
+            ('inet:fqdn', 'cool.vertex.newp'),
+        )
         async with self.getTestCore() as core:
             async with await core.snap() as snap:
                 node = await snap.addNode(formname, valu)
                 self.checkNode(node, (expected_ndef, expected_props))
+            await self.checkNodes(core, expected_nodes)
 
     async def test_user(self):
         formname = 'inet:user'
@@ -1452,6 +1475,19 @@ class InetModelTest(s_t_utils.SynTest):
                 node = await snap.addNode(formname, valu, props=input_props)
                 self.checkNode(node, (expected_ndef, expected_props))
 
+            nodes = await core.nodes('inet:fqdn')
+            self.len(2, nodes)
+
+            expected_nodes = (
+                ('inet:ipv4', 0x08070605),
+                ('inet:ipv6', '::ffff:8.7.6.5'),
+                ('inet:fqdn', 'newp.com'),
+                ('inet:user', 'hehe'),
+            )
+            nodes = await core.nodes('[inet:web:action=(test,) :acct:user=hehe :acct:site=newp.com :client="tcp://::ffff:8.7.6.5"]')
+            self.len(1, nodes)
+            await self.checkNodes(core, expected_nodes)
+
     async def test_web_chprofile(self):
         formname = 'inet:web:chprofile'
         valu = 32 * 'a'
@@ -1477,6 +1513,15 @@ class InetModelTest(s_t_utils.SynTest):
                 node = await snap.addNode(formname, valu, props=input_props)
                 self.checkNode(node, (expected_ndef, expected_props))
 
+            expected_nodes = (
+                ('inet:ipv4', 0x08070605),
+                ('inet:ipv6', '::ffff:8.7.6.5'),
+                ('inet:user', 'hehe'),
+            )
+            self.len(1, await core.nodes(
+                '[inet:web:chprofile=(test,) :acct:user=hehe :acct:site=newp.com :client="tcp://::ffff:8.7.6.5"]'))
+            await self.checkNodes(core, expected_nodes)
+
     async def test_web_file(self):
         formname = 'inet:web:file'
         valu = (('vertex.link', 'vertexmc'), 64 * 'f')
@@ -1495,11 +1540,18 @@ class InetModelTest(s_t_utils.SynTest):
             'client': 'tcp://::1',
             'client:ipv6': '::1'
         }
+        expected_nodes = (
+            ('inet:ipv6', '::1'),
+            ('inet:fqdn', 'vertex.link'),
+            ('file:bytes', 'sha256:' + 64 * 'f'),
+            ('inet:user', 'vertexmc'),
+        )
         expected_ndef = (formname, (valu[0], 'sha256:' + valu[1]))
         async with self.getTestCore() as core:
             async with await core.snap() as snap:
                 node = await snap.addNode(formname, valu, props=input_props)
                 self.checkNode(node, (expected_ndef, expected_props))
+            await self.checkNodes(core, expected_nodes)
 
     async def test_web_follows(self):
         formname = 'inet:web:follows'
@@ -1649,6 +1701,7 @@ class InetModelTest(s_t_utils.SynTest):
             'acct': ('vertex.link', 'vertexmc'),
             'text': 'my cooL POST',
             'time': 0,
+            'deleted': True,
             'url': 'https://vertex.link/mypost',
             'client': 'tcp://1.2.3.4',
             'file': 64 * 'f',
@@ -1671,6 +1724,7 @@ class InetModelTest(s_t_utils.SynTest):
             'client:ipv4': 0x01020304,
             'text': 'my cooL POST',
             'time': 0,
+            'deleted': True,
             'url': 'https://vertex.link/mypost',
             'file': 'sha256:' + 64 * 'f',
             'replyto': 32 * 'b',
@@ -1692,6 +1746,11 @@ class InetModelTest(s_t_utils.SynTest):
             'client:ipv6': '::1',
         }
 
+        expected_nodes = (
+            ('inet:fqdn', 'vertex.link'),
+            ('inet:group', 'ninjas'),
+        )
+
         expected_ndef = (formname, valu)
         async with self.getTestCore() as core:
             async with await core.snap() as snap:
@@ -1702,6 +1761,8 @@ class InetModelTest(s_t_utils.SynTest):
                 self.checkNode(node, (('inet:web:post', node2), expected2))
                 self.len(2, await core.nodes('inet:web:post -> inet:web:hashtag'))
 
+                await self.checkNodes(core, expected_nodes)
+
     async def test_whois_contact(self):
         formname = 'inet:whois:contact'
         valu = (('vertex.link', '@2015'), 'regiStrar')
@@ -1738,10 +1799,14 @@ class InetModelTest(s_t_utils.SynTest):
             'whois:fqdn': 'vertex.link'
         }
         expected_ndef = (formname, (('vertex.link', 1420070400000), 'registrar'))
+        expected_nodes = (
+            ('inet:fqdn', 'vertex.link'),
+        )
         async with self.getTestCore() as core:
             async with await core.snap() as snap:
                 node = await snap.addNode(formname, valu, props=input_props)
                 self.checkNode(node, (expected_ndef, expected_props))
+            await self.checkNodes(core, expected_nodes)
 
     async def test_whois_rar(self):
         formname = 'inet:whois:rar'
@@ -1982,8 +2047,20 @@ class InetModelTest(s_t_utils.SynTest):
                 self.eq(443, node.get('server:port'))
                 self.eq(0x01020304, node.get('server:ipv4'))
 
-                strn = await snap.getNodeByNdef(('it:dev:str', 'Hi There'))
-                self.nn(strn)
+            expected_nodes = (
+                ('it:dev:str', 'Hi There'),
+                ('inet:ipv4', 0x01020304),
+            )
+            await self.checkNodes(core, expected_nodes)
+
+            node = await core.nodes('[inet:banner=("tcp://::ffff:8.7.6.5", sup)]')
+            self.len(1, node)
+            expected_nodes = (
+                ('it:dev:str', 'sup'),
+                ('inet:ipv4', 0x08070605),
+                ('inet:ipv6', '::ffff:8.7.6.5'),
+            )
+            await self.checkNodes(core, expected_nodes)
 
     async def test_search_query(self):
         async with self.getTestCore() as core:
