@@ -57,10 +57,17 @@ class ProjModelTest(s_test.SynTest):
 
             with self.raises(s_exc.AuthDeny):
                 await core.callStorm('$lib.projects.get($proj).sprints.get($sprint).status = current', opts=opts)
+            with self.raises(s_exc.AuthDeny):
+                await core.callStorm('$lib.projects.get($proj).sprints.get($sprint).desc = badset', opts=opts)
             await visi.addRule((True, ('project', 'sprint', 'set', 'status')), gateiden=proj)
+            await visi.addRule((True, ('project', 'sprint', 'set', 'desc')), gateiden=proj)
             await core.callStorm('$lib.projects.get($proj).sprints.get($sprint).status = $lib.null', opts=opts)
             self.len(0, await core.nodes('proj:sprint:status'))
             await core.callStorm('$lib.projects.get($proj).sprints.get($sprint).status = current', opts=opts)
+            await core.callStorm('$lib.projects.get($proj).sprints.get($sprint).desc = cooldesc', opts=opts)
+            self.len(1, await core.nodes('proj:sprint:desc'))
+            await core.callStorm('$lib.projects.get($proj).sprints.get($sprint).desc = $lib.null', opts=opts)
+            self.len(0, await core.nodes('proj:sprint:desc'))
             self.len(1, await core.nodes('proj:sprint:status=current'))
 
             # we created the ticket, so we can set these...
